@@ -7,7 +7,7 @@ import click
 from .airfilter_util import FilterType, FilterTypeUtil
 from .click_common import EnumType, command, format_output
 from .exceptions import DeviceException
-from .miot_device import MiotDevice
+from .miot_device import DeviceStatus, MiotDevice
 
 _LOGGER = logging.getLogger(__name__)
 _MAPPING = {
@@ -46,6 +46,27 @@ _MAPPING = {
     "app_extra": {"siid": 15, "piid": 1},
 }
 
+# https://miot-spec.org/miot-spec-v2/instance?type=urn:miot-spec-v2:device:air-purifier:0000A007:zhimi-mb4:2
+_MODEL_AIRPURIFIER_MB4 = {
+    # Air Purifier
+    "power": {"siid": 2, "piid": 1},
+    "mode": {"siid": 2, "piid": 4},
+    # Environment
+    "aqi": {"siid": 3, "piid": 4},
+    # Filter
+    "filter_life_remaining": {"siid": 4, "piid": 1},
+    "filter_hours_used": {"siid": 4, "piid": 3},
+    # Alarm
+    "buzzer": {"siid": 6, "piid": 1},
+    # Screen
+    "led_brightness_level": {"siid": 7, "piid": 2},
+    # Physical Control Locked
+    "child_lock": {"siid": 8, "piid": 1},
+    # custom-service
+    "motor_speed": {"siid": 9, "piid": 1},
+    "favorite_rpm": {"siid": 9, "piid": 3},
+}
+
 
 class AirPurifierMiotException(DeviceException):
     pass
@@ -64,7 +85,7 @@ class LedBrightness(enum.Enum):
     Off = 2
 
 
-class AirPurifierMiotStatus:
+class BasicAirPurifierMiotStatus(DeviceStatus):
     """Container for status reports from the air purifier."""
 
     def __init__(self, data: Dict[str, Any]) -> None:
@@ -84,8 +105,77 @@ class AirPurifierMiotStatus:
     @property
     def aqi(self) -> int:
         """Air quality index."""
+        # zhimi-airpurifier-mb3 returns 1 as AQI value if the measurement was
+        # unsuccessful
+        if self.data["aqi"] == 1:
+            return None
         return self.data["aqi"]
 
+    @property
+    def mode(self) -> OperationMode:
+        """Current operation mode."""
+        return OperationMode(self.data["mode"])
+
+    @property
+    def buzzer(self) -> Optional[bool]:
+        """Return True if buzzer is on."""
+        if self.data["buzzer"] is not None:
+            return self.data["buzzer"]
+
+        return None
+
+    @property
+    def child_lock(self) -> bool:
+        """Return True if child lock is on."""
+        return self.data["child_lock"]
+
+    @property
+    def filter_life_remaining(self) -> int:
+        """Time until the filter should be changed."""
+        return self.data["filter_life_remaining"]
+
+    @property
+    def filter_hours_used(self) -> int:
+        """How long the filter has been in use."""
+        return self.data["filter_hours_used"]
+
+    @property
+    def motor_speed(self) -> int:
+        """Speed of the motor."""
+        return self.data["motor_speed"]
+
+
+class AirPurifierMiotStatus(BasicAirPurifierMiotStatus):
+    """Container for status reports from the air purifier.
+
+    Mi Air Purifier 3/3H (zhimi.airpurifier.mb3) response (MIoT format)
+
+    [
+        {'did': 'power', 'siid': 2, 'piid': 2, 'code': 0, 'value': True},
+        {'did': 'fan_level', 'siid': 2, 'piid': 4, 'code': 0, 'value': 1},
+        {'did': 'mode', 'siid': 2, 'piid': 5, 'code': 0, 'value': 2},
+        {'did': 'humidity', 'siid': 3, 'piid': 7, 'code': 0, 'value': 38},
+        {'did': 'temperature', 'siid': 3, 'piid': 8, 'code': 0, 'value': 22.299999},
+        {'did': 'aqi', 'siid': 3, 'piid': 6, 'code': 0, 'value': 2},
+        {'did': 'filter_life_remaining', 'siid': 4, 'piid': 3, 'code': 0, 'value': 45},
+        {'did': 'filter_hours_used', 'siid': 4, 'piid': 5, 'code': 0, 'value': 1915},
+        {'did': 'buzzer', 'siid': 5, 'piid': 1, 'code': 0, 'value': False},
+        {'did': 'buzzer_volume', 'siid': 5, 'piid': 2, 'code': -4001},
+        {'did': 'led_brightness', 'siid': 6, 'piid': 1, 'code': 0, 'value': 1},
+        {'did': 'led', 'siid': 6, 'piid': 6, 'code': 0, 'value': True},
+        {'did': 'child_lock', 'siid': 7, 'piid': 1, 'code': 0, 'value': False},
+        {'did': 'favorite_level', 'siid': 10, 'piid': 10, 'code': 0, 'value': 2},
+        {'did': 'favorite_rpm', 'siid': 10, 'piid': 7, 'code': 0, 'value': 770},
+        {'did': 'motor_speed', 'siid': 10, 'piid': 8, 'code': 0, 'value': 769},
+        {'did': 'use_time', 'siid': 12, 'piid': 1, 'code': 0, 'value': 6895800},
+        {'did': 'purify_volume', 'siid': 13, 'piid': 1, 'code': 0, 'value': 222564},
+        {'did': 'average_aqi', 'siid': 13, 'piid': 2, 'code': 0, 'value': 2},
+        {'did': 'filter_rfid_tag', 'siid': 14, 'piid': 1, 'code': 0, 'value': '81:6b:3f:32:84:4b:4'},
+        {'did': 'filter_rfid_product_id', 'siid': 14, 'piid': 3, 'code': 0, 'value': '0:0:31:31'},
+        {'did': 'app_extra', 'siid': 15, 'piid': 1, 'code': 0, 'value': 0}
+    ]
+    """
+
     @property
     def average_aqi(self) -> int:
         """Average of the air quality index."""
@@ -109,11 +199,6 @@ class AirPurifierMiotStatus:
         """Current fan level."""
         return self.data["fan_level"]
 
-    @property
-    def mode(self) -> OperationMode:
-        """Current operation mode."""
-        return OperationMode(self.data["mode"])
-
     @property
     def led(self) -> bool:
         """Return True if LED is on."""
@@ -130,14 +215,6 @@ class AirPurifierMiotStatus:
 
         return None
 
-    @property
-    def buzzer(self) -> Optional[bool]:
-        """Return True if buzzer is on."""
-        if self.data["buzzer"] is not None:
-            return self.data["buzzer"]
-
-        return None
-
     @property
     def buzzer_volume(self) -> Optional[int]:
         """Return buzzer volume."""
@@ -146,27 +223,12 @@ class AirPurifierMiotStatus:
 
         return None
 
-    @property
-    def child_lock(self) -> bool:
-        """Return True if child lock is on."""
-        return self.data["child_lock"]
-
     @property
     def favorite_level(self) -> int:
         """Return favorite level, which is used if the mode is ``favorite``."""
         # Favorite level used when the mode is `favorite`.
         return self.data["favorite_level"]
 
-    @property
-    def filter_life_remaining(self) -> int:
-        """Time until the filter should be changed."""
-        return self.data["filter_life_remaining"]
-
-    @property
-    def filter_hours_used(self) -> int:
-        """How long the filter has been in use."""
-        return self.data["filter_hours_used"]
-
     @property
     def use_time(self) -> int:
         """How long the device has been active in seconds."""
@@ -177,11 +239,6 @@ class AirPurifierMiotStatus:
         """The volume of purified air in cubic meter."""
         return self.data["purify_volume"]
 
-    @property
-    def motor_speed(self) -> int:
-        """Speed of the motor."""
-        return self.data["motor_speed"]
-
     @property
     def filter_rfid_product_id(self) -> Optional[str]:
         """RFID product ID of installed filter."""
@@ -199,68 +256,112 @@ class AirPurifierMiotStatus:
             self.filter_rfid_tag, self.filter_rfid_product_id
         )
 
-    def __repr__(self) -> str:
-        s = (
-            "<AirPurifierMiotStatus power=%s, "
-            "aqi=%s, "
-            "average_aqi=%s, "
-            "temperature=%s, "
-            "humidity=%s%%, "
-            "fan_level=%s, "
-            "mode=%s, "
-            "led=%s, "
-            "led_brightness=%s, "
-            "buzzer=%s, "
-            "buzzer_volume=%s, "
-            "child_lock=%s, "
-            "favorite_level=%s, "
-            "filter_life_remaining=%s, "
-            "filter_hours_used=%s, "
-            "use_time=%s, "
-            "purify_volume=%s, "
-            "motor_speed=%s, "
-            "filter_rfid_product_id=%s, "
-            "filter_rfid_tag=%s, "
-            "filter_type=%s>"
-            % (
-                self.power,
-                self.aqi,
-                self.average_aqi,
-                self.temperature,
-                self.humidity,
-                self.fan_level,
-                self.mode,
-                self.led,
-                self.led_brightness,
-                self.buzzer,
-                self.buzzer_volume,
-                self.child_lock,
-                self.favorite_level,
-                self.filter_life_remaining,
-                self.filter_hours_used,
-                self.use_time,
-                self.purify_volume,
-                self.motor_speed,
-                self.filter_rfid_product_id,
-                self.filter_rfid_tag,
-                self.filter_type,
-            )
-        )
-        return s
+
+class AirPurifierMB4Status(BasicAirPurifierMiotStatus):
+    """
+    Container for status reports from the  Mi Air Purifier 3C (zhimi.airpurifier.mb4).
+
+    {
+        'power': True,
+        'mode': 1,
+        'aqi': 2,
+        'filter_life_remaining': 97,
+        'filter_hours_used': 100,
+        'buzzer': True,
+        'led_brightness_level': 8,
+        'child_lock': False,
+        'motor_speed': 392,
+        'favorite_rpm': 500
+    }
+
+    Response (MIoT format)
+
+    [
+        {'did': 'power', 'siid': 2, 'piid': 1, 'code': 0, 'value': True},
+        {'did': 'mode', 'siid': 2, 'piid': 4, 'code': 0, 'value': 1},
+        {'did': 'aqi', 'siid': 3, 'piid': 4, 'code': 0, 'value': 3},
+        {'did': 'filter_life_remaining', 'siid': 4, 'piid': 1, 'code': 0, 'value': 97},
+        {'did': 'filter_hours_used', 'siid': 4, 'piid': 3, 'code': 0, 'value': 100},
+        {'did': 'buzzer', 'siid': 6, 'piid': 1, 'code': 0, 'value': True},
+        {'did': 'led_brightness_level', 'siid': 7, 'piid': 2, 'code': 0, 'value': 8},
+        {'did': 'child_lock', 'siid': 8, 'piid': 1, 'code': 0, 'value': False},
+        {'did': 'motor_speed', 'siid': 9, 'piid': 1, 'code': 0, 'value': 388},
+        {'did': 'favorite_rpm', 'siid': 9, 'piid': 3, 'code': 0, 'value': 500}
+    ]
+
+    """
+
+    @property
+    def led_brightness_level(self) -> int:
+        """Return brightness level."""
+        return self.data["led_brightness_level"]
+
+    @property
+    def favorite_rpm(self) -> int:
+        """Return favorite rpm level."""
+        return self.data["favorite_rpm"]
 
 
-class AirPurifierMiot(MiotDevice):
+class BasicAirPurifierMiot(MiotDevice):
     """Main class representing the air purifier which uses MIoT protocol."""
 
-    def __init__(
-        self,
-        ip: str = None,
-        token: str = None,
-        start_id: int = 0,
-        debug: int = 0,
-        lazy_discover: bool = True,
-    ) -> None:
-        super().__init__(_MAPPING, ip, token, start_id, debug, lazy_discover)
+    @command(default_output=format_output("Powering on"))
+    def on(self):
+        """Power on."""
+        return self.set_property("power", True)
+
+    @command(default_output=format_output("Powering off"))
+    def off(self):
+        """Power off."""
+        return self.set_property("power", False)
+
+    @command(
+        click.argument("rpm", type=int),
+        default_output=format_output("Setting favorite motor speed '{rpm}' rpm"),
+    )
+    def set_favorite_rpm(self, rpm: int):
+        """Set favorite motor speed."""
+        # Note: documentation says the maximum is 2300, however, the purifier may return an error for rpm over 2200.
+        if rpm < 300 or rpm > 2300 or rpm % 10 != 0:
+            raise AirPurifierMiotException(
+                "Invalid favorite motor speed: %s. Must be between 300 and 2300 and divisible by 10"
+                % rpm
+            )
+        return self.set_property("favorite_rpm", rpm)
+
+    @command(
+        click.argument("mode", type=EnumType(OperationMode)),
+        default_output=format_output("Setting mode to '{mode.value}'"),
+    )
+    def set_mode(self, mode: OperationMode):
+        """Set mode."""
+        return self.set_property("mode", mode.value)
+
+    @command(
+        click.argument("buzzer", type=bool),
+        default_output=format_output(
+            lambda buzzer: "Turning on buzzer" if buzzer else "Turning off buzzer"
+        ),
+    )
+    def set_buzzer(self, buzzer: bool):
+        """Set buzzer on/off."""
+        return self.set_property("buzzer", buzzer)
+
+    @command(
+        click.argument("lock", type=bool),
+        default_output=format_output(
+            lambda lock: "Turning on child lock" if lock else "Turning off child lock"
+        ),
+    )
+    def set_child_lock(self, lock: bool):
+        """Set child lock on/off."""
+        return self.set_property("child_lock", lock)
+
+
+class AirPurifierMiot(BasicAirPurifierMiot):
+    """Main class representing the air purifier which uses MIoT protocol."""
+
+    mapping = _MAPPING
 
     @command(
         default_output=format_output(
@@ -298,16 +399,6 @@ class AirPurifierMiot(MiotDevice):
             }
         )
 
-    @command(default_output=format_output("Powering on"))
-    def on(self):
-        """Power on."""
-        return self.set_property("power", True)
-
-    @command(default_output=format_output("Powering off"))
-    def off(self):
-        """Power off."""
-        return self.set_property("power", False)
-
     @command(
         click.argument("level", type=int),
         default_output=format_output("Setting fan level to '{level}'"),
@@ -318,20 +409,6 @@ class AirPurifierMiot(MiotDevice):
             raise AirPurifierMiotException("Invalid fan level: %s" % level)
         return self.set_property("fan_level", level)
 
-    @command(
-        click.argument("rpm", type=int),
-        default_output=format_output("Setting favorite motor speed '{rpm}' rpm"),
-    )
-    def set_favorite_rpm(self, rpm: int):
-        """Set favorite motor speed."""
-        # Note: documentation says the maximum is 2300, however, the purifier may return an error for rpm over 2200.
-        if rpm < 300 or rpm > 2300 or rpm % 10 != 0:
-            raise AirPurifierMiotException(
-                "Invalid favorite motor speed: %s. Must be between 300 and 2300 and divisible by 10"
-                % rpm
-            )
-        return self.set_property("favorite_rpm", rpm)
-
     @command(
         click.argument("volume", type=int),
         default_output=format_output("Setting sound volume to {volume}"),
@@ -344,21 +421,14 @@ class AirPurifierMiot(MiotDevice):
             )
         return self.set_property("buzzer_volume", volume)
 
-    @command(
-        click.argument("mode", type=EnumType(OperationMode)),
-        default_output=format_output("Setting mode to '{mode.value}'"),
-    )
-    def set_mode(self, mode: OperationMode):
-        """Set mode."""
-        return self.set_property("mode", mode.value)
-
     @command(
         click.argument("level", type=int),
         default_output=format_output("Setting favorite level to {level}"),
     )
     def set_favorite_level(self, level: int):
-        """Set the favorite level used when the mode is `favorite`,
-        should be  between 0 and 14.
+        """Set the favorite level used when the mode is `favorite`.
+
+        Needs to be between 0 and 14.
         """
         if level < 0 or level > 14:
             raise AirPurifierMiotException("Invalid favorite level: %s" % level)
@@ -383,22 +453,44 @@ class AirPurifierMiot(MiotDevice):
         """Turn led on/off."""
         return self.set_property("led", led)
 
-    @command(
-        click.argument("buzzer", type=bool),
-        default_output=format_output(
-            lambda buzzer: "Turning on buzzer" if buzzer else "Turning off buzzer"
-        ),
-    )
-    def set_buzzer(self, buzzer: bool):
-        """Set buzzer on/off."""
-        return self.set_property("buzzer", buzzer)
+
+class AirPurifierMB4(BasicAirPurifierMiot):
+    """Main class representing the air purifier which uses MIoT protocol."""
+
+    mapping = _MODEL_AIRPURIFIER_MB4
 
     @command(
-        click.argument("lock", type=bool),
         default_output=format_output(
-            lambda lock: "Turning on child lock" if lock else "Turning off child lock"
-        ),
+            "",
+            "Power: {result.power}\n"
+            "AQI: {result.aqi} μg/m³\n"
+            "Mode: {result.mode}\n"
+            "LED brightness level: {result.led_brightness_level}\n"
+            "Buzzer: {result.buzzer}\n"
+            "Child lock: {result.child_lock}\n"
+            "Filter life remaining: {result.filter_life_remaining} %\n"
+            "Filter hours used: {result.filter_hours_used}\n"
+            "Motor speed: {result.motor_speed} rpm\n"
+            "Favorite RPM: {result.favorite_rpm} rpm\n",
+        )
     )
-    def set_child_lock(self, lock: bool):
-        """Set child lock on/off."""
-        return self.set_property("child_lock", lock)
+    def status(self) -> AirPurifierMB4Status:
+        """Retrieve properties."""
+
+        return AirPurifierMB4Status(
+            {
+                prop["did"]: prop["value"] if prop["code"] == 0 else None
+                for prop in self.get_properties_for_mapping()
+            }
+        )
+
+    @command(
+        click.argument("level", type=int),
+        default_output=format_output("Setting LED brightness level to {level}"),
+    )
+    def set_led_brightness_level(self, level: int):
+        """Set led brightness level (0..8)."""
+        if level < 0 or level > 8:
+            raise AirPurifierMiotException("Invalid brightness level: %s" % level)
+
+        return self.set_property("led_brightness_level", level)
