@@ -39,7 +39,8 @@ class ChuangmiIr(Device):
     def learn(self, key: int = 1):
         """Learn an infrared command.
 
-        :param int key: Storage slot, must be between 1 and 1000000"""
+        :param int key: Storage slot, must be between 1 and 1000000
+        """
 
         if key < 1 or key > 1000000:
             raise ChuangmiIrException("Invalid storage slot.")
@@ -61,7 +62,8 @@ class ChuangmiIr(Device):
         Negative response (chuangmi.ir.v2):
         {'error': {'code': -5003, 'message': 'learn timeout'}, 'id': 17}
 
-        :param int key: Slot to read from"""
+        :param int key: Slot to read from
+        """
 
         if key < 1 or key > 1000000:
             raise ChuangmiIrException("Invalid storage slot.")
@@ -71,24 +73,27 @@ class ChuangmiIr(Device):
         """Play a captured command.
 
         :param str command: Command to execute
-        :param int frequency: Execution frequency"""
+        :param int frequency: Execution frequency
+        """
         return self.send("miIO.ir_play", {"freq": frequency, "code": command})
 
     def play_pronto(self, pronto: str, repeats: int = 1):
-        """Play a Pronto Hex encoded IR command.
-        Supports only raw Pronto format, starting with 0000.
+        """Play a Pronto Hex encoded IR command. Supports only raw Pronto format,
+        starting with 0000.
 
         :param str pronto: Pronto Hex string.
-        :param int repeats: Number of extra signal repeats."""
+        :param int repeats: Number of extra signal repeats.
+        """
         return self.play_raw(*self.pronto_to_raw(pronto, repeats))
 
     @classmethod
     def pronto_to_raw(cls, pronto: str, repeats: int = 1):
-        """Play a Pronto Hex encoded IR command.
-        Supports only raw Pronto format, starting with 0000.
+        """Play a Pronto Hex encoded IR command. Supports only raw Pronto format,
+        starting with 0000.
 
         :param str pronto: Pronto Hex string.
-        :param int repeats: Number of extra signal repeats."""
+        :param int repeats: Number of extra signal repeats.
+        """
         if repeats < 0:
             raise ChuangmiIrException("Invalid repeats value")
 
@@ -139,18 +144,19 @@ class ChuangmiIr(Device):
         else:
             command_type, command, *command_args = command.split(":")
 
-        if command_type == "raw":
-            play_method = self.play_raw
-            arg_types = [int]
-        elif command_type == "pronto":
-            play_method = self.play_pronto
-            arg_types = [int]
-        else:
-            raise ChuangmiIrException("Invalid command type")
-
+        arg_types = [int]
         if len(command_args) > len(arg_types):
             raise ChuangmiIrException("Invalid command arguments count")
 
+        if command_type not in ["raw", "pronto"]:
+            raise ChuangmiIrException("Invalid command type")
+
+        if command_type == "raw":
+            play_method = self.play_raw
+
+        elif command_type == "pronto":
+            play_method = self.play_pronto
+
         try:
             command_args = [t(v) for v, t in zip(command_args, arg_types)]
         except Exception as ex:
