@@ -1,8 +1,8 @@
 import codecs
 import inspect
-import ipaddress
 import logging
 from functools import partial
+from ipaddress import ip_address
 from typing import Callable, Dict, Optional, Union  # noqa: F401
 
 import zeroconf
@@ -11,6 +11,9 @@ from . import (
     AirConditionerMiot,
     AirConditioningCompanion,
     AirConditioningCompanionMcn02,
+    AirDogX3,
+    AirDogX5,
+    AirDogX7SM,
     AirFresh,
     AirFreshT2017,
     AirHumidifier,
@@ -27,6 +30,7 @@ from . import (
     Cooker,
     Device,
     Fan,
+    FanLeshow,
     FanMiot,
     Heater,
     PhilipsBulb,
@@ -108,6 +112,9 @@ DEVICE_MAP = {
     "xiaomi.aircondition.mc2": AirConditionerMiot,
     "xiaomi.aircondition.mc4": AirConditionerMiot,
     "xiaomi.aircondition.mc5": AirConditionerMiot,
+    "airdog-airpurifier-x3": AirDogX3,
+    "airdog-airpurifier-x5": AirDogX5,
+    "airdog-airpurifier-x7sm": AirDogX7SM,
     "zhimi-airpurifier-m1": AirPurifier,  # mini model
     "zhimi-airpurifier-m2": AirPurifier,  # mini model 2
     "zhimi-airpurifier-ma1": AirPurifier,  # ms model
@@ -165,6 +172,7 @@ DEVICE_MAP = {
     ),
     "lumi-camera-aq2": AqaraCamera,
     "yeelink-light-": Yeelight,
+    "leshow-fan-ss4": FanLeshow,
     "zhimi-fan-v2": partial(Fan, model=MODEL_FAN_V2),
     "zhimi-fan-v3": partial(Fan, model=MODEL_FAN_V3),
     "zhimi-fan-sa1": partial(Fan, model=MODEL_FAN_SA1),
@@ -197,9 +205,19 @@ def pretty_token(token):
     return codecs.encode(token, "hex").decode()
 
 
+def get_addr_from_info(info):
+    addrs = info.addresses
+    if len(addrs) > 1:
+        _LOGGER.warning(
+            "More than single IP address in the advertisement, using the first one"
+        )
+
+    return str(ip_address(addrs[0]))
+
+
 def other_package_info(info, desc):
     """Return information about another package supporting the device."""
-    return "%s @ %s, check %s" % (info.name, ipaddress.ip_address(info.address), desc)
+    return "Found %s at %s, check %s" % (info.name, get_addr_from_info(info), desc)
 
 
 def create_device(name: str, addr: str, device_cls: partial) -> Device:
@@ -227,8 +245,8 @@ class Listener:
         self.found_devices = {}  # type: Dict[str, Device]
 
     def check_and_create_device(self, info, addr) -> Optional[Device]:
-        """Create a corresponding :class:`Device` implementation
-        for a given info and address.."""
+        """Create a corresponding :class:`Device` implementation for a given info and
+        address.."""
         name = info.name
         for identifier, v in DEVICE_MAP.items():
             if name.startswith(identifier):
@@ -253,7 +271,8 @@ class Listener:
 
     def add_service(self, zeroconf, type, name):
         info = zeroconf.get_service_info(type, name)
-        addr = str(ipaddress.ip_address(info.address))
+        addr = get_addr_from_info(info)
+
         if addr not in self.found_devices:
             dev = self.check_and_create_device(info, addr)
             self.found_devices[addr] = dev
@@ -261,13 +280,15 @@ class Listener:
 
 class Discovery:
     """mDNS discoverer for miIO based devices (_miio._udp.local).
-    Calling :func:`discover_mdns` will cause this to subscribe for updates
-    on ``_miio._udp.local`` until any key is pressed, after which a dict
-    of detected devices is returned."""
+
+    Calling :func:`discover_mdns` will cause this to subscribe for updates on
+    ``_miio._udp.local`` until any key is pressed, after which a dict of detected
+    devices is returned.
+    """
 
     @staticmethod
     def discover_mdns() -> Dict[str, Device]:
-        """Discover devices with mdns until """
+        """Discover devices with mdns until any keyboard input."""
         _LOGGER.info("Discovering devices with mDNS, press any key to quit...")
 
         listener = Listener()
